@@ -35,7 +35,7 @@
 #include <gtk/gtkcolorsel.h>
 #include <gtk/gtkcolorseldialog.h>
 #include <gdk/gdkkeysyms.h>
-#include "gtkcombobox.h"
+#include "gtkextracombobox.h"
 #include "gtkcolorcombo.h"
 #include "gtkextra-marshal.h"
 
@@ -125,7 +125,7 @@ static void 	    gtk_color_combo_get_color_name  (GdkColor *color,
 						     gchar *name);
 static void 	    color_to_hex		    (gint color, gchar string[5]);
 
-static GtkComboBoxClass *parent_class = NULL;
+static GtkExtraComboBoxClass *parent_class = NULL;
 
 static void
 gtk_color_combo_class_init (GtkColorComboClass * klass)
@@ -257,11 +257,11 @@ gtk_color_combo_update (GtkWidget * widget, GtkColorCombo * color_combo)
 
   }
 
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(GTK_COMBO_BOX(color_combo)->arrow), FALSE);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(GTK_EXTRA_COMBO_BOX(color_combo)->arrow), FALSE);
 
-  gtk_grab_remove(GTK_COMBO_BOX(color_combo)->popwin);
+  gtk_grab_remove(GTK_EXTRA_COMBO_BOX(color_combo)->popwin);
   gdk_pointer_ungrab(GDK_CURRENT_TIME);
-  gtk_widget_hide(GTK_COMBO_BOX(color_combo)->popwin);
+  gtk_widget_hide(GTK_EXTRA_COMBO_BOX(color_combo)->popwin);
   return;
 }
 
@@ -353,7 +353,7 @@ gtk_color_combo_customize(GtkButton *button, gpointer data)
 static void
 gtk_color_combo_realize(GtkWidget *widget)
 {
-  GtkComboBox *combo;
+  GtkExtraComboBox *combo;
   GtkColorCombo *color_combo;
   GdkPixmap *color_pixmap;
   GtkWidget *pixmap;
@@ -366,7 +366,7 @@ gtk_color_combo_realize(GtkWidget *widget)
 
   GTK_WIDGET_CLASS (parent_class)->realize (widget);
 
-  combo = GTK_COMBO_BOX(widget);
+  combo = GTK_EXTRA_COMBO_BOX(widget);
   color_combo = GTK_COLOR_COMBO(widget);
 
   box = gtk_vbox_new(FALSE,0);
@@ -394,7 +394,7 @@ gtk_color_combo_realize(GtkWidget *widget)
   }
 
 
-  gtk_container_add(GTK_CONTAINER(GTK_COMBO_BOX(color_combo)->frame), box);
+  gtk_container_add(GTK_CONTAINER(GTK_EXTRA_COMBO_BOX(color_combo)->frame), box);
   gtk_box_pack_start(GTK_BOX(box), color_combo->table, TRUE, TRUE, 0);
   gtk_widget_show(box);
   gtk_widget_show(color_combo->table);
@@ -491,7 +491,7 @@ gtk_color_combo_get_type ()
 	NULL,
 	(GtkClassInitFunc) NULL,
       };
-      color_combo_type = gtk_type_unique (gtk_combobox_get_type (), &color_combo_info);
+      color_combo_type = gtk_type_unique (gtk_extra_combobox_get_type (), &color_combo_info);
     }
   return color_combo_type;
 }
