@@ -3,7 +3,7 @@
 --               GtkAda - Ada95 binding for Gtk+/Gnome               --
 --                                                                   --
 --   Copyright (C) 1998-2000 E. Briot, J. Brobecker and A. Charlet   --
---                Copyright (C) 2000-2003 ACT-Europe                 --
+--                Copyright (C) 2000-2004 ACT-Europe                 --
 --                                                                   --
 -- This library is free software; you can redistribute it and/or     --
 -- modify it under the terms of the GNU General Public               --
@@ -29,6 +29,7 @@
 -----------------------------------------------------------------------
 */
 
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -46,6 +47,10 @@
 #include <gtk/gtkwidget.h>
 
 #include <gtk/gtktreemodel.h>
+#include <gtk/gtktreestore.h>
+#include <gtk/gtktreesortable.h>
+#include <gtk/gtkenums.h>
+
 
 void
 ada_tree_model_get_value
@@ -267,8 +272,10 @@ ada_initialize_class_record
       class_info->base_finalize = NULL;
       class_info->class_init = NULL;
       class_info->class_finalize = NULL;
-      class_info->class_data = NULL; /* Would be nice to use this for the set_property???*/
-      class_info->instance_size = query.instance_size;  /* ??? should be parameter */
+      class_info->class_data = NULL;
+         /* Would be nice to use this for the set_property???*/
+      class_info->instance_size = query.instance_size;
+         /* ??? should be parameter */
       class_info->n_preallocs = 0;
       class_info->instance_init = NULL;
       class_info->value_table = NULL;
@@ -321,8 +328,9 @@ ada_initialize_class_record
 	      + sizeof (void*));
 
       virtual = (gpointer*) malloc (num_virtual_functions * sizeof (gpointer));
-      *((gpointer**)((char*)klass + query.class_size + nsignals * sizeof (void*)))
-	= virtual;
+      *((gpointer**)((char*)klass
+		     + query.class_size
+		     + nsignals * sizeof (void*))) = virtual;
 
       for (j = 0; j < num_virtual_functions; j++) {
 	virtual [j] = virtual_functions [j];
@@ -332,10 +340,9 @@ ada_initialize_class_record
   else
     {
       klass = g_type_class_ref (G_TYPE_FROM_CLASS (old_class_record));
-
     }
 
-  G_OBJECT_GET_CLASS (object) = klass;
+  ((GTypeInstance*)object)->g_class = (GTypeClass*) klass;
   return klass;
 }
 
@@ -1080,12 +1087,12 @@ gint ada_gdk_event_get_direction (GdkEvent * event)
     return ada_gdk_invalid_gint_value;
 
   switch (event->type)
-    { 
+    {
     case GDK_SCROLL:
       return event->scroll.direction;
     default:
       break;
-    } 
+    }
   return ada_gdk_invalid_gint_value;
 }
 
@@ -3474,12 +3481,19 @@ ada_tree_iter_copy (const GtkTreeIter *source,
 #ifdef _WIN32
 
 #include <windows.h>
+#include <gdk/gdkwin32.h>
 void
 ada_gdk_move_pointer (gint x, gint y)
 {
   SetCursorPos (x, y);
 }
 
+void *
+ada_gdk_get_window_id (GdkWindow *w)
+{
+  return (void *)GDK_WINDOW_HWND (w);
+}
+
 #else
 #include <gdk/gdkx.h>
 
@@ -3493,4 +3507,35 @@ ada_gdk_move_pointer (gint x, gint y)
   XWarpPointer (xdisplay, None, xroot_window, 0, 0, 0, 0, x, y);
 }
 
+void *
+ada_gdk_get_window_id (GdkWindow *w)
+{
+  return (void *) GDK_WINDOW_XID (w);
+}
+
 #endif
+
+PangoUnderline
+ada_pango_underline_error (void)
+{
+#ifdef HAVE_PANGO_UNDERLINE_ERROR
+  return PANGO_UNDERLINE_ERROR;
+#else
+  return PANGO_UNDERLINE_SINGLE;
+#endif
+}
+
+/******************************************
+ ** Handling of tree Freeze/Thaw         **
+ ******************************************/
+
+gint ada_gtk_tree_view_freeze_sort (GtkTreeStore* tree) {
+  gint save = tree->sort_column_id;
+  tree->sort_column_id = -2;
+  return save;
+}
+
+void ada_gtk_tree_view_thaw_sort (GtkTreeStore* tree, gint id) {
+  gtk_tree_sortable_set_sort_column_id
+    (GTK_TREE_SORTABLE (tree), id, tree->order);
+}
